@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-search.c 5326 2006-12-02 15:03:22Z pborelli $
+ * $Id: gedit-commands-search.c 5631 2007-06-17 15:07:49Z paolo $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -536,7 +536,8 @@ _gedit_cmd_search_find (GtkAction   *action,
 		 * it is already open
 		 */
 
-		gtk_window_present (GTK_WINDOW (data));
+		gedit_search_dialog_present_with_time (GEDIT_SEARCH_DIALOG (data),
+						       GDK_CURRENT_TIME);
 
 		return;
 	}
@@ -618,7 +619,8 @@ _gedit_cmd_search_replace (GtkAction   *action,
 			gedit_search_dialog_set_show_replace (GEDIT_SEARCH_DIALOG (data),
 							      TRUE);
 
-		gtk_window_present (GTK_WINDOW (data));
+		gedit_search_dialog_present_with_time (GEDIT_SEARCH_DIALOG (data),
+						       GDK_CURRENT_TIME);
 
 		return;
 	}
