@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-view.c 5796 2007-08-14 17:26:09Z pborelli $ 
+ * $Id: gedit-view.c 5852 2007-08-27 11:11:45Z paolo $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -305,10 +305,10 @@ gedit_view_init (GeditView *view)
 		      "wrap_mode", gedit_prefs_manager_get_wrap_mode (),
 		      "show_line_numbers", gedit_prefs_manager_get_display_line_numbers (),
 		      "auto_indent", gedit_prefs_manager_get_auto_indent (),
-		      "tabs_width", gedit_prefs_manager_get_tabs_size (),
+		      "tab_width", gedit_prefs_manager_get_tabs_size (),
 		      "insert_spaces_instead_of_tabs", gedit_prefs_manager_get_insert_spaces (),
-		      "show_margin", gedit_prefs_manager_get_display_right_margin (), 
-		      "margin", gedit_prefs_manager_get_right_margin_position (),
+		      "show_right_margin", gedit_prefs_manager_get_display_right_margin (), 
+		      "right_margin_position", gedit_prefs_manager_get_right_margin_position (),
 		      "highlight_current_line", gedit_prefs_manager_get_highlight_current_line (),
 		      "smart_home_end", gedit_prefs_manager_get_smart_home_end (),
 		      "indent_on_tab", TRUE,
